@@ -1,7 +1,7 @@
 #coding:utf-8
 """
 Модуль с базовыми классами/интерфейсами, которые необходимы
-для работы подсистемы m3_ext.ui
+для работы подсистемы m3_ext_demo.ui
 
 Created on 01.03.2010
 
@@ -11,17 +11,11 @@ Created on 01.03.2010
 
 import datetime
 import decimal
-import collections
-
-from django import template as django_template
-from django.conf import settings
 
 from m3_ext.ui import render_template, render_component
 from m3_ext.ui import generate_client_id, normalize
 from m3 import date2str
 
-import js
-
 
 class ExtComponentException(Exception):
     """
@@ -30,50 +24,6 @@ class ExtComponentException(Exception):
     pass
 
 
-#==============================================================================
-class ExtUIScriptRenderer(object):
-    """
-    @deprecated: Использовать метод render конечного компонента
-
-    Класс, отвечающий за рендер файла скрипта, который
-    будет отправлен клиенту.
-    """
-    def __init__(self):
-        # шаблон, в который осуществляется вывод содержимого
-        # скрипта
-        self.template = 'ext-script/ext-ui-script.js'
-        # компонент, содержимое которого выводится в шаблон
-        self.component = None
-
-    def render(self):
-        result = ''
-        try:
-            result = self.component.render()
-        except AttributeError:
-            result = ''
-        return result
-
-    def render_globals(self):
-        result = ''
-        try:
-            result = self.component.render_globals()
-        except AttributeError:
-            result = ''
-        return result
-
-    def get_script(self):
-        """
-        Генерация скрипта для отправки на клиентское рабочее место.
-        """
-        context = django_template.Context({'renderer': self})
-        template = django_template.loader.get_template(self.template)
-        script = template.render(context)
-        if settings.DEBUG:
-            script = js.JSNormalizer().normalize(script)
-        return script
-
-
-#==============================================================================
 class BaseExtComponent(object):
     """
     Базовый класс для всех компонентов пользовательского интерфейса
@@ -82,7 +32,7 @@ class BaseExtComponent(object):
         # Каждый компонент может иметь шаблон, в котором он будет рендериться
         self.template = ''
 
-        # @deprecated: Только окно (наследник BaseExtWindow)
+        # :deprecated: Только окно (наследник BaseExtWindow)
         # может иметь данный атрибут
         self.template_globals = ''
 
@@ -93,10 +43,6 @@ class BaseExtComponent(object):
         # an instance of m3.actions.ActionContext class
         self.action_context = None
 
-        # рендерер, используемый для вывода соответствующего компонента
-        self.renderer = ExtUIScriptRenderer()
-        #self.renderer.component = self
-
         # Словарь обработчиков на события
         self._listeners = {}
 
@@ -112,20 +58,12 @@ class BaseExtComponent(object):
         # Имя компонента в нотации ExtJs (Например Ext.form.Panel)
         self._ext_name = None
 
-        # квалифицирующее имя контрола
-        # (в пределах некоторого базового компонента)
-        # формируется путем присоединения
-        # к имени текущего компонента квалифицирующих
-        # имен родительских контейнеров.
-        # квалицирющее имя текущего компонента
-        # формируется из наименования атрибута
-        self.qname = ''
-
     def render(self):
         """
         Возвращает "кусок" javascript кода, который используется для
         отображения самого компонента. За рендер полного javascript
         отвечает метод get_script()
+        :rtype: str
         """
         self.pre_render()
         return render_component(self)
@@ -133,8 +71,8 @@ class BaseExtComponent(object):
     def render_globals(self):
         """
         Рендерит и возвращает js-код, который помещен в template_globals
+        :rtype: str
         """
-        self.pre_render_globals()
         if self.template_globals:
             return render_template(
                 self.template_globals,
@@ -147,18 +85,6 @@ class BaseExtComponent(object):
         """
         pass
 
-    def pre_render_globals(self):
-        """
-        Вызывается перед началом работы метода render_globals
-        """
-        pass
-
-    def get_script(self):
-        """
-        Генерация скрипта для отправки на клиентское рабочее место.
-        """
-        return self.renderer.get_script()
-
     def init_component(self, *args, **kwargs):
         """
         Заполняет атрибуты экземпляра значениями в kwargs,
@@ -170,10 +96,9 @@ class BaseExtComponent(object):
                 % (k, self.__class__.__name__))
             self.__setattr__(k, v)
 
-    #deprecated:
     def t_render_listeners(self):
         """
-        @deprecated: Если рендеринг не в шаблоне,
+        :deprecated: Если рендеринг не в шаблоне,
         то при вызове render_base_config информация о подписчиках на события
         уже будут в конфиге
 
@@ -184,7 +109,7 @@ class BaseExtComponent(object):
 
     def t_render_simple_listeners(self):
         """
-        @deprecated: Конфиг должен рендериться в render_base_config
+        :deprecated: Конфиг должен рендериться в render_base_config
         """
         return '{%s}' % ','.join([
             '%s:%s' % (k, v)
@@ -213,6 +138,9 @@ class BaseExtComponent(object):
         """
         Проверка на не юникодную строку в которой есть русские символы
         Если есть русские символы необходимо использовать юникод!
+        :param string: строка для проверки
+        :type string: str / unicode
+        :raise: Exception
         """
         try:
             unicode(string)
@@ -226,6 +154,18 @@ class BaseExtComponent(object):
         """
         Управляет правильной установкой (в зависимости от типа)
         параметров контрола
+        :param src_list: список словарей
+        :type src_list: list
+        :param extjs_name: Оригинальное название атрибута в ExtJs
+        :type: extjs_name: str
+        :param item: значение атрибута в М3
+        :type item: basestring, bool, int, float, decimal, long, dict
+        :param condition: Условие добавления в конфиг.
+        :type condition: bool
+        :param depth: глубина обхода
+        :type depth: int
+
+        :raise: ExtComponentException
         """
         conf_dict = {}
         res = None
@@ -283,27 +223,45 @@ class BaseExtComponent(object):
         """
         Добавляет значение в конфиг компонента ExtJs,
         для последующей передачи в конструктор JS
-        @param extjs_name: Оригинальное название атрибута в ExtJs
-        @param item: Значение атрибута в М3
-        @param condition: Условие добавления в конфиг.
-        Бывает полезно чтобы не использовать лишний if
+        :param extjs_name: Оригинальное название атрибута в ExtJs
+        :type: extjs_name: str
+        :param item: Значение атрибута в М3
+        :param condition: Условие добавления в конфиг.
+        :type condition: bool
+
+        .. note::
+            Бывает полезно чтобы не использовать лишний if
         """
         self._put_base_value(self._config_list, extjs_name, item, condition)
 
     def _put_params_value(self, extjs_name, item, condition=True):
         """
         Обертка для упаковки детализированного конфига компонента
+        :param extjs_name: Оригинальное название атрибута в ExtJs
+        :type: extjs_name: str
+        :param item: Значение атрибута в М3
+        :param condition: Условие добавления в конфиг.
+        :type condition: bool
         """
         self._put_base_value(self._param_list, extjs_name, item, condition)
 
     def _set_base_value(self, src_list, key, value):
         """
         Устанавливает значение по ключу
+        :param src_list: список словарей структуры
+        :type src_list: list
+        :param key: ключ
+        :param value: значение
+        :raise: AssertionError
         """
         def set_value_to_dict(src_dict, key, value):
             """
             Вспомогательная функция, позволяет рекурсивно собрать все вложенные
             структуры-словари
+            :param src_dict: словарь структуры
+            :type src_dict: dict
+            :param key: ключ
+            :param value: значение
             """
             for k, v in src_dict.items():
                 if isinstance(v, dict):
@@ -335,7 +293,9 @@ class BaseExtComponent(object):
     def _get_base_str(self, src_list):
         """
         Возвращает структуру в json-формате
-        @param src_list: Список словарей, словари могут быть вложенными
+        :param src_list: Список словарей, словари могут быть вложенными
+        :type src_list: list
+
         Пример структуры:
         [
             {...},
@@ -350,6 +310,8 @@ class BaseExtComponent(object):
             """
             Вспомогательная функция, позволяет рекурсивно собрать все вложенные
             структуры-словари
+            :param src_dict: структура-словарь
+            :type src_dict: dict
             """
             tmp_list = []
             for k, v in src_dict.items():
@@ -382,110 +344,7 @@ class BaseExtComponent(object):
         """
         return self._get_base_str(self._param_list)
 
-    def nested_components(self):
-        """
-        Метод получения списка внутренних (по отношению
-        к текущему) компонентов.
 
-        Данный метод следует переопределять в унаследованных классах
-        """
-        return []
-
-    def prepare_qnames(self):
-        """
-        Метод вычисляет квалицицирующие имена контролов.
-
-        Квалифицирующие имена не вычисляются неявно. Т.е. для получения
-        qname контрола необходимо явно вызвать данный метод.
-
-        Примеры того, как формируются квалифицирующие имена контролов см. в
-        m3/src/tests/ui/ext_tests/tests.py (test case: QNamesTests)
-        """
-        if self.qname:
-            # квалицицирующие имена этого и вложенных в него контролов
-            # типа были вычислены заранееы
-            return
-
-        # вычисляем квалицицирующее имя для текущего компонента.
-        self.qname = self.__class__.__name__
-
-        # очередь компонентов, для которых необходимо определить qnames
-        # очередь состоит из кортежей (компонент, родительский компонент)
-        queue = collections.deque([self])
-
-        # основной цикл, в котором происходит вычисление
-        # квалифицирующих имен
-        while len(queue) > 0:
-            cmp = queue.popleft()
-            # проверяем, может быть, квалифицирующее имя
-            # уже было вычислено ранее
-            if not cmp:
-                continue
-
-            if not cmp.qname:
-                # формируем имя компонента на основе его типа,
-                # qname родительского контрола
-                # и индекса внутри компонентов базового контрола
-                pass
-
-            # получаем вложенные компоненты
-            nested = cmp.nested_components()
-            # словарь, в котором в качестве ключей будут классы контролов,
-            # а в значениях - количество контролов указанного типа.
-            # это необходимо для того, чтобы формировать имена
-            # типа ...__ExtButton0
-            cmp_indicies = {}
-            # формируем транспонированный словарь атрибутов
-            # ключом будут вложенные атрибуты BaseExtComponent
-            transposed_cmp_dict = {}
-            for name, value in cmp.__dict__.iteritems():
-                if isinstance(value, BaseExtComponent):
-                    transposed_cmp_dict[value] = name
-
-            for nested_cmp in nested:
-                if nested_cmp and not nested_cmp.qname:
-                    attr_name = transposed_cmp_dict.get(nested_cmp, '')
-                    if attr_name:
-                        # вложенный компонент присутствует в атрибутах
-                        # родительского контейнера.
-                        if '__' in attr_name and hasattr(
-                                cmp, attr_name + '_qname'):
-                            qname = getattr(cmp, attr_name + '_qname')
-                        else:
-                            qname = attr_name
-                        nested_cmp.qname = cmp.qname + '__' + qname
-                    else:
-                        component_index = cmp_indicies.get(
-                            nested_cmp.__class__, -1) + 1
-                        nested_cmp.qname = '%s__%s%s' % (
-                            cmp.qname,
-                            nested_cmp.__class__.__name__,
-                            component_index
-                        )
-                        cmp_indicies[nested_cmp.__class__] = component_index
-
-                    # включаем компонент в очередь на дальнейшую обработку
-                    queue.append(nested_cmp)
-
-            # теперь мы должны пройтись по необработанным ранее компонентам и
-            # выставить у них qname
-            for cmp_in_attr, attr_name in transposed_cmp_dict.iteritems():
-                if not cmp_in_attr.qname:
-                    cmp_in_attr.qname = cmp.qname + '__' + attr_name
-
-            # У ДАННОГО МЕХАНИЗМА ЕСТЬ ОДИН НЕПРИЯТНЫЙ САЙД ЭФФЕКТ.
-            # в случае, если в атрибуты этого или одно из вложенных компонентов
-            # попадет нечто левое унаследованное от BaseExtComponent,
-            # то его qname будет заполнен некоторым значением.
-            # чтобы избежать этого, возможно, стоит предусмотреть нечто,
-            # что будет описывать именно те компоненты,
-            # которые подлежат обработке.
-            # но хождение по этому нечту приведет
-            # к замедлению времени вычисления
-            # квалифицирующих имен компонентов.
-
-
-#==============================================================================
 class ExtUIComponent(BaseExtComponent):
     """
     Базовый класс для компонентов визуального интерфейса
@@ -552,7 +411,7 @@ class ExtUIComponent(BaseExtComponent):
 
     def t_render_style(self):
         """
-        @deprecated: Использовать рендеринг в render_base_config
+        :deprecated: Использовать рендеринг в render_base_config
         """
         return '{%s}' % ','.join(
             ['"%s":"%s"' % i for i in self.style.items()]
@@ -590,38 +449,35 @@ class ExtUIComponent(BaseExtComponent):
             self._put_config_value('labelStyle', self.t_render_label_style())
         self._put_config_value('hideLabel', self.hide_label, self.hide_label)
 
-    def pre_make_read_only(
-            self, access_off=True, exclude_list=[], *args, **kwargs):
+    def make_read_only(
+            self, access_off=True, exclude_list=(), *args, **kwargs):
         """
-        Выполняется перед методом make_read_only, определяет находится ли
-        данный компонент в списке исключений
-        (в список может передаваться имя объекта, или даже сам объект).
-        Если компонент в списке исключенний, то
-        действие метода становится противопложным.
-        Т.е. если вызывали make_read_only - компонент не будет отключаться, и
-        наоборот, если вызывали make_read_only(False) объект будет отключен.
+        :param access_off: переменная регулирует вкл\выкл режима для чтения.
+        :type access_off: bool
+        :param exclude_list: список, содержит в себе имена элементов,
+            которые не надо выключать.
+            Позволяет сделать компонент недоступным для изменения.
+            Обязательно должен быть переопределен в наследуемых классах.
+        :type exclude_list: list
+
+        .. note::
+        При вызове метода без параметров, используется параметр по-умолчанию
+        access_off=True, в этом случае метод делает компонент, и все контролы
+        расположенные на нем неизменяемыми.
+        _make_read_only(False) соответственно делает компонент доступным для
+        изменения, так же как и все контролы на нем.
         """
         if (
             (self in exclude_list) or
             (hasattr(self, 'name') and self.name and self.name in exclude_list)
         ):
-            access_off = not access_off
-        return access_off
+            actual_access_off = not access_off
+        else:
+            actual_access_off = access_off
 
-    def make_read_only(
-            self, access_off=True, exclude_list=[], *args, **kwargs):
-        """
-        @access_off - переменная регулирует вкл\выкл режима для чтения.
-        @exclude_list - список, содержит в себе имена элементов,
-        которые не надо выключать.
-        Позволяет сделать компонент недоступным для изменения.
-        Обязательно должен быть переопределен в наследуемых классах.
-        При вызове метода без параметров, используется параметр по-умолчанию
-        access_off=True, в этом случае метод делает компонент, и все контролы
-        расположенные на нем неизменяемыми.
-        make_read_only(False) соответственно делает компонент доступным для
-        изменения, так же как и все контролы на нем.
-        """
-        excp_name = self.__class__.__name__
-        raise NotImplementedError(
-            u'В компоненте %s не переопределен базовый метод.' % excp_name)
+        return self._make_read_only(
+            actual_access_off, exclude_list, *args, **kwargs)
+
+    def _make_read_only(
+            self, access_off=True, exclude_list=(), *args, **kwargs):
+        raise NotImplementedError()
