@@ -4,6 +4,7 @@ Created on 25.02.2010
 
 @author: akvarats
 """
+import weakref
 
 from django.conf import settings
 
@@ -14,25 +15,19 @@ from m3_ext.ui import render_template
 
 from m3_ext.ui.containers.base import BaseExtContainer
 from m3_ext.ui.controls.base import BaseExtControl
-from m3_ext.ui.base import ExtUIScriptRenderer
-from m3_ext.ui import js
 
 
-class ExtWindowRenderer(ExtUIScriptRenderer):
+class ExtWindowRenderer(object):
     """
     Рендерер для скрипта на показ окна
     """
-    def __init__(self):
-        self.template = 'ext-script/ext-windowscript.js'
-        self.window = None
+    def __init__(self, common_template):
+        self.common_template = common_template
 
-    def get_script(self):
-        script = render_template(
-            self.template, {'renderer': self, 'window': self.window}
+    def get_script(self, window):
+        return render_template(
+            self.common_template, {'window': window}
         )
-        if settings.DEBUG:
-            script = js.JSNormalizer().normalize(script)
-        return script
 
 
 class BaseExtWindow(ExtUIComponent):
@@ -52,8 +47,7 @@ class BaseExtWindow(ExtUIComponent):
         # Шаблон, который будет отрендерен после основного
         self.template_globals = ''
 
-        self.renderer = ExtWindowRenderer()
-        self.renderer.window = self
+        self.renderer = ExtWindowRenderer('ext-script/ext-windowscript.js')
 
         # Название
         self._ext_name = 'Ext.m3.Window'
@@ -135,6 +129,7 @@ class BaseExtWindow(ExtUIComponent):
     def t_render_layout_config(self):
         """
         Рендерит конфиг, если указан layout
+        :rtype: str
         """
         return '{%s}' % ','.join([
             '%s:"%s"' % (k, v)
@@ -252,6 +247,8 @@ class BaseExtWindow(ExtUIComponent):
         """
         Осуществляет поиск экземпляра
         во вложенных объектах по имени экземпляра
+        :param name: имя экземпляра
+        :type name: str
         """
         for item in self._items:
             if hasattr(item, 'name') and name == getattr(item, 'name'):
@@ -287,9 +284,10 @@ class BaseExtWindow(ExtUIComponent):
         return str(self.closable)
 
     def t_render_keys(self):
-        '''
+        """
         Биндинг множества кнопок к их действиям
-        '''
+        :rtype: str
+        """
         return '[%s]' % ','.join([
             '{%s}' % ','.join([
                 '%s:%s' % i for i in key.items()
@@ -298,9 +296,10 @@ class BaseExtWindow(ExtUIComponent):
         ])
 
     def _help_topic_full_path(self):
-        '''
+        """
         Возвращает квалицифирующее имя топика помощи
-        '''
+        :rtype: str
+        """
         if not self.help_topic:
             return ''
         assert isinstance(self.help_topic, tuple)
@@ -309,32 +308,14 @@ class BaseExtWindow(ExtUIComponent):
             '#' + self.help_topic[1] if len(self.help_topic) > 1 else ''
         )
 
-    def nested_components(self):
-        '''
-        Возвращает список вложенных компонентов
-        '''
-        nested = super(BaseExtWindow, self).nested_components()
-        # произвольные вложенные элементы
-        nested.extend(self.items)
-        # кнопки
-        nested.extend(self.buttons)
-        # топ и футтер бары как контейнет
-        nested.extend([self.top_bar, self.footer_bar])
-
-        return nested
-
-    def make_read_only(
-            self, access_off=True, exclude_list=[], *args, **kwargs):
-        # Описание в базовом классе ExtUiComponent.
-        # Обрабатываем исключения.
-        access_off = self.pre_make_read_only(
-            access_off, exclude_list, *args, **kwargs)
-        # Выключаем\включаем компоненты.
-        # Задаем собственный атрибут окна.
+    def _make_read_only(
+            self, access_off=True, exclude_list=None, *args, **kwargs):
+        exclude_list = exclude_list or []
         self.read_only = access_off
         # Перебираем итемы.
         for item in self.__items:
-            item.make_read_only(self.read_only, exclude_list, *args, **kwargs)
+            item.make_read_only(
+                self.read_only, exclude_list, *args, **kwargs)
         # Перебираем бары.
         bar_typle = (self.footer_bar, self.bottom_bar, self.top_bar)
         for bar in bar_typle:
@@ -351,3 +332,6 @@ class BaseExtWindow(ExtUIComponent):
                 assert isinstance(button, BaseExtControl)
                 button.make_read_only(
                     self.read_only, exclude_list, *args, **kwargs)
+
+    def get_script(self):
+        return self.renderer.get_script(self)
