@@ -11,8 +11,6 @@ from m3_ext.ui.fields import ExtSearchField
 from m3_ext.ui.controls import ExtButton
 from m3_ext.ui.containers import (
     ExtContextMenu,
-    ExtPanel,
-    ExtListView,
     ExtToolBar,
     ExtTree,
     ExtGrid
@@ -21,11 +19,15 @@ from base import BaseExtWindow
 
 
 #==============================================================================
-# TODO: Необходимо отрефакторить данный класс под внутриклассовый рендеринг
+# TODO: Необходимо отрефакторить данный класс под внутриклассовый рендеринг 15.08.11
+# TODO: Необходимо отрефакторить нахер все тут 29.01.13
+# TODO: Кто-нибудь, выкиньте уже этот код <near future>
+# deprecated: use objectpack
 class ExtDictionaryWindow(BaseExtWindow):
-    '''
+    """
+    :deprecated:
     Базовое окно для линейного, иерархичесого и совмещенного справочника
-    '''
+    """
 
     # Режим отображения
     LIST_MODE = 0
@@ -58,9 +60,6 @@ class ExtDictionaryWindow(BaseExtWindow):
         # Дерево
         self.tree = None
 
-        # TODO: не используется, убрать
-        self.list_view = None
-
         # Контрол поиска для грида
         self.search_text_grid = None
 
@@ -70,9 +69,6 @@ class ExtDictionaryWindow(BaseExtWindow):
         # Кнопка выбора, если mode = SELECT_MODE
         self.select_button = None
 
-        # TODO: не используется. т.к не используется list_view
-        self._panel_list_view = None
-
         # Окно может находится в двух положениях:
         # просто список записей и список выбора записи/записей
         # По умолчанию справочник открыт в режиме списка
@@ -120,6 +116,8 @@ class ExtDictionaryWindow(BaseExtWindow):
 
         self.allow_copy = False
 
+        self._text_on_select = None
+
         self.init_component(*args, **kwargs)
 
     @property
@@ -141,10 +139,6 @@ class ExtDictionaryWindow(BaseExtWindow):
             self.select_button = select_btn
 
         elif value == ExtDictionaryWindow.LIST_MODE:
-            if self._panel_list_view:
-                self.items.remove(self._panel_list_view)
-                self.list_view = None
-                self._panel_list_view = None
             if self.select_button:
                 self.buttons.remove(self.select_button)
                 self.select_button = None
@@ -155,35 +149,14 @@ class ExtDictionaryWindow(BaseExtWindow):
             self.buttons.insert(0, select_btn)
             self.select_button = select_btn
 
-        # панель с историей выбора пока отключена
-        if value in (
-            ExtDictionaryWindow.SELECT_MODE,
-            ExtDictionaryWindow.MULTI_SELECT_MODE
-        ):
-            button_panel = ExtPanel(
-                title='История выбора',
-                region='south',
-                min_height=100,
-                collapsible=True,
-                split=True
-            )
-            list_view = ExtListView()
-            button_panel.items.append(list_view)
-            self._panel_list_view = button_panel
-            self.list_view = list_view
-
         self._mode = value
 
-    def make_read_only(
-            self, access_off=True, exclude_list=[], *args, **kwargs):
-        # Описание в базовом классе ExtUIComponent.
-        # Обрабатываем исключения.
-        access_off = self.pre_make_read_only(
-            access_off, exclude_list, *args, **kwargs)
-        # Выключаем\включаем компоненты.
-        # Задаем собственный атрибут окна.
+    def _make_read_only(
+            self, access_off=True, exclude_list=None, *args, **kwargs):
+        exclude_list = exclude_list or []
         self.read_only = access_off
-        super(ExtDictionaryWindow, self).make_read_only(
+
+        super(ExtDictionaryWindow, self)._make_read_only(
             self.read_only, exclude_list, *args, **kwargs)
         if self.tree:
             # Включаем обратно refresh, ибо он нужен.
@@ -282,7 +255,7 @@ class ExtDictionaryWindow(BaseExtWindow):
     def _add_separator_tree(
             self, to_tbar=True, to_node_menu=True,
             to_tree_menu=True, to_menu=None):
-        '''Добавление разделителя в контролы дерева'''
+        """Добавление разделителя в контролы дерева"""
         if to_menu:
             to_menu.add_separator()
         if to_tbar:
@@ -428,9 +401,9 @@ class ExtDictionaryWindow(BaseExtWindow):
             component.disabled = True
 
     def init_grid_components(self):
-        '''
+        """
         Идентификация грида
-        '''
+        """
         if not self.grid:
             grid = ExtGrid(region='center')
             grid.load_mask = True
@@ -483,9 +456,9 @@ class ExtDictionaryWindow(BaseExtWindow):
                 self.grid.sm = ExtGridCheckBoxSelModel()
 
     def init_tree_components(self):
-        '''
+        """
         Идентификация дерева
-        '''
+        """
         if not self.tree:
             tree = ExtTree(width=180)
             tree.handler_contextmenu = ExtContextMenu()
